aboutsummaryrefslogtreecommitdiffstats
path: root/drv_LCD2USB.c
diff options
context:
space:
mode:
Diffstat (limited to 'drv_LCD2USB.c')
-rw-r--r--drv_LCD2USB.c13
1 files changed, 6 insertions, 7 deletions
diff --git a/drv_LCD2USB.c b/drv_LCD2USB.c
index ae3fccf..5e2fc72 100644
--- a/drv_LCD2USB.c
+++ b/drv_LCD2USB.c
@@ -1,7 +1,7 @@
-/* $Id: drv_LCD2USB.c 773 2007-02-25 12:39:09Z michael $
- * $URL: https://ssl.bulix.org/svn/lcd4linux/branches/0.10.1/drv_LCD2USB.c $
+/* $Id: drv_LCD2USB.c 1130 2010-10-31 19:21:45Z harbaum $
+ * $URL: https://ssl.bulix.org/svn/lcd4linux/trunk/drv_LCD2USB.c $
*
* driver for USB2LCD display interface
* see http://www.harbaum.org/till/lcd2usb for schematics
*
* Copyright 2005 Till Harbaum <till@harbaum.org>
@@ -98,7 +98,6 @@ static char *device_id = NULL, *bus_id = NULL;
static usb_dev_handle *lcd;
static int controllers = 0;
-extern int usb_debug;
extern int got_signal;
/****************************************/
@@ -120,7 +119,7 @@ static int drv_L2U_open(char *bus_id, char *device_id)
if (device_id != NULL)
info("%s: scanning for device id: %s", Name, device_id);
- usb_debug = 0;
+ usb_set_debug(0);
usb_init();
usb_find_busses();
@@ -570,7 +569,7 @@ static void plugin_brightness(RESULT * result, RESULT * arg1)
/* list models */
int drv_L2U_list(void)
{
- printf("generic");
+ printf("LCD2USB homebrew USB interface for HD44780 text displays");
return 0;
}
@@ -582,7 +581,7 @@ int drv_L2U_init(const char *section, const int quiet)
int asc255bug;
int ret;
- info("%s: %s", Name, "$Rev: 773 $");
+ info("%s: %s", Name, "$Rev: 1130 $");
/* display preferences */
XRES = 5; /* pixel width of one char */
@@ -1,7 +1,7 @@
*
- * driver for USB2LCD display interface
+ * driver for LCD2USB display interface
* see http://www.harbaum.org/till/lcd2usb for schematics
*